==> okteta_0.25.4.orig.tar.xz: okteta-0.25.4/libs/kasten/gui/controller/togglebutton.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "togglebutton.h"
#include "togglebutton_p.h"

namespace Kasten {

ToggleButton::ToggleButton(const QIcon& icon, const QString& text, const QString& toolTip, QWidget* parent)
    : QToolButton(parent)
    , d(new ToggleButtonPrivate(this))
{
    setIcon(icon);
    setText(text);
    setToolTip(toolTip);
}

ToggleButton::ToggleButton(const QString& text, const QString& toolTip, QWidget* parent)
    : QToolButton(parent)
    , d(new ToggleButtonPrivate(this))
{
    setText(text);
    setToolTip(toolTip);
}

ToggleButton::~ToggleButton()
{
    delete d;
}

void ToggleButton::setCheckedState(const QIcon& icon, const QString& text, const QString& toolTip)
{
    d->setOtherState(icon, text, toolTip);
}

void ToggleButton::setCheckedState(const QString& text, const QString& toolTip)
{
    d->setOtherState(QIcon(), text, toolTip);
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/gui/controller/togglebutton.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "togglebutton.hpp"
#include "togglebutton_p.hpp"

namespace Kasten {

ToggleButton::ToggleButton(const QIcon& icon, const QString& text, const QString& toolTip, QWidget* parent)
    : QToolButton(parent)
    , d_ptr(new ToggleButtonPrivate(this))
{
    setIcon(icon);
    setText(text);
    setToolTip(toolTip);
}

ToggleButton::ToggleButton(const QString& text, const QString& toolTip, QWidget* parent)
    : QToolButton(parent)
    , d_ptr(new ToggleButtonPrivate(this))
{
    setText(text);
    setToolTip(toolTip);
}

ToggleButton::~ToggleButton() = default;

void ToggleButton::setCheckedState(const QIcon& icon, const QString& text, const QString& toolTip)
{
    Q_D(ToggleButton);

    d->setOtherState(icon, text, toolTip);
}

void ToggleButton::setCheckedState(const QString& text, const QString& toolTip)
{
    Q_D(ToggleButton);

    d->setOtherState(QIcon(), text, toolTip);
}

}
